@@ -192,8 +192,6 @@ func TestConsoleLogObjectsWithGoTypes(t *testing.T) {
 
 	expFields := logrus.Fields{"source": "console"}
 	for _, tt := range tests {
-		tt := tt
-
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -242,7 +240,6 @@ func TestConsoleLog(t *testing.T) {
 	}
 
 	for i, tt := range tests {
-		tt := tt
 		t.Run(fmt.Sprintf("case%d", i), func(t *testing.T) {
 			t.Parallel()
 
@@ -294,7 +291,6 @@ func TestConsoleLevels(t *testing.T) {
 		{in: `{foo:"bar"}`, exp: `{"foo":"bar"}`},
 	}
 	for name, level := range levels {
-		name, level := name, level
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 			for _, tt := range argsets {
@@ -363,16 +359,13 @@ func TestFileConsole(t *testing.T) {
 		preExistingText = "Prexisting file\n"
 	)
 	for name, level := range levels {
-		name, level := name, level
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 			for args, result := range argsets {
-				args, result := args, result
 				t.Run(args, func(t *testing.T) {
 					t.Parallel()
 					// whether the file is existed before logging
 					for msg, deleteFile := range preExisting {
-						msg, deleteFile := msg, deleteFile
 						t.Run(msg, func(t *testing.T) {
 							t.Parallel()
 							f, err := os.CreateTemp(t.TempDir(), "") //nolint:forbidigo // fix with https://github.com/grafana/k6/issues/2565
