@@ -49,7 +49,7 @@ func mapPage(vu moduleVU, p *common.Page) mapping { //nolint:gocognit,cyclop
 			return k6ext.Promise(vu.Context(), func() (any, error) {
 				// It's safe to close the taskqueue for this targetID (if one
 				// exists).
-				vu.taskQueueRegistry.close(p.TargetID())
+				vu.close(p.TargetID())
 
 				return nil, p.Close() //nolint:wrapcheck
 			})
@@ -610,7 +610,7 @@ func mapPageOn(vu moduleVU, p *common.Page) func(common.PageOnEventName, sobek.C
 
 		// Run the the event handler in the task queue to
 		// ensure that the handler is executed on the event loop.
-		tq := vu.taskQueueRegistry.get(ctx, p.TargetID())
+		tq := vu.get(ctx, p.TargetID())
 		eventHandler := func(event common.PageOnEvent) error {
 			mapping := pageOnEvent.mapp(vu, event)
 
