@@ -4,6 +4,7 @@
 package tests
 
 import (
+	"fmt"
 	"testing"
 	"time"
 
@@ -156,6 +157,13 @@ func TestLocator(t *testing.T) {
 				require.Error(t, lo.Fill(value, nil))
 			},
 		},
+		{
+			"First", func(_ *testBrowser, p *common.Page) {
+				text, err := p.Locator("a", nil).First().InnerText(nil)
+				require.NoError(t, err)
+				require.Equal(t, `Click`, text)
+			},
+		},
 		{
 			"Focus", func(_ *testBrowser, p *common.Page) {
 				focused := func() bool {
@@ -227,6 +235,20 @@ func TestLocator(t *testing.T) {
 				})
 			},
 		},
+		{
+			"Last", func(_ *testBrowser, p *common.Page) {
+				text, err := p.Locator("div", nil).Last().InnerText(nil)
+				require.NoError(t, err)
+				require.Equal(t, `bye`, text)
+			},
+		},
+		{
+			"Nth", func(_ *testBrowser, p *common.Page) {
+				text, err := p.Locator("a", nil).Nth(0).InnerText(nil)
+				require.NoError(t, err)
+				require.Equal(t, `Click`, text)
+			},
+		},
 		{
 			"Press", func(_ *testBrowser, p *common.Page) {
 				lo := p.Locator("#inputText", nil)
@@ -315,7 +337,6 @@ func TestLocator(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -452,7 +473,6 @@ func TestLocator(t *testing.T) {
 		},
 	}
 	for _, tt := range sanityTests {
-		tt := tt
 		t.Run("timeout/"+tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -465,7 +485,6 @@ func TestLocator(t *testing.T) {
 	}
 
 	for _, tt := range sanityTests {
-		tt := tt
 		t.Run("strict/"+tt.name, func(t *testing.T) {
 			t.Parallel()
 			tb := newTestBrowser(t, withFileServer())
@@ -535,7 +554,6 @@ func TestLocatorElementState(t *testing.T) {
 	}
 
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.state, func(t *testing.T) {
 			t.Parallel()
 
@@ -597,7 +615,6 @@ func TestLocatorElementState(t *testing.T) {
 		},
 	}
 	for _, tt := range sanityTests {
-		tt := tt
 		t.Run("timeout/"+tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -610,7 +627,6 @@ func TestLocatorElementState(t *testing.T) {
 	}
 
 	for _, tt := range sanityTests {
-		tt := tt
 		t.Run("strict/"+tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -672,15 +688,11 @@ func TestLocatorShadowDOM(t *testing.T) {
 func TestSelectOption(t *testing.T) {
 	t.Parallel()
 
-	tb := newTestBrowser(t,
-		withFileServer(),
-	)
-	defer tb.Browser.Close()
+	tb := newTestBrowser(t, withFileServer())
+	tb.vu.ActivateVU()
+	tb.vu.StartIteration(t)
 
-	vu, _, _, cleanUp := startIteration(t)
-	defer cleanUp()
-
-	got := vu.RunPromise(t, `
+	got := tb.vu.RunPromise(t, `
 		const page = await browser.newPage();
 
 		await page.goto('%s');
@@ -725,3 +737,91 @@ func TestSelectOption(t *testing.T) {
 	`, tb.staticURL("select_options.html"))
 	assert.Equal(t, sobek.Undefined(), got.Result())
 }
+
+func TestCount(t *testing.T) {
+	t.Parallel()
+
+	tests := []struct {
+		name string
+		do   func(*testBrowser, *common.Page)
+	}{
+		{
+			"0", func(_ *testBrowser, p *common.Page) {
+				l := p.Locator("#NOTEXIST", nil)
+				c, err := l.Count()
+				require.NoError(t, err)
+				require.Equal(t, 0, c)
+			},
+		},
+		{
+			"1", func(_ *testBrowser, p *common.Page) {
+				l := p.Locator("#link", nil)
+				c, err := l.Count()
+				require.NoError(t, err)
+				require.Equal(t, 1, c)
+			},
+		},
+		{
+			"3", func(_ *testBrowser, p *common.Page) {
+				l := p.Locator("a", nil)
+				c, err := l.Count()
+				require.NoError(t, err)
+				require.Equal(t, 3, c)
+			},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			t.Parallel()
+
+			tb := newTestBrowser(t, withFileServer())
+			p := tb.NewPage(nil)
+			opts := &common.FrameGotoOptions{
+				Timeout: common.DefaultTimeout,
+			}
+			_, err := p.Goto(
+				tb.staticURL("locators.html"),
+				opts,
+			)
+			tt.do(tb, p)
+			require.NoError(t, err)
+		})
+	}
+}
+
+func TestReactInput(t *testing.T) {
+	t.Parallel()
+
+	tests := []struct {
+		name string
+		do   func(*testBrowser, *common.Page)
+	}{
+		{
+			"Fill", func(_ *testBrowser, p *common.Page) {
+				const value = "test@example.com"
+				lo := p.Locator("input[placeholder='Username or email']", nil)
+				require.NoError(t, lo.Fill(value, nil))
+				inputValue, err := p.InnerText("p[id='react-state']", common.NewFrameInnerTextOptions(p.MainFrame().Timeout()))
+				require.NoError(t, err)
+				require.Equal(t, fmt.Sprintf("React state: %q", value), inputValue)
+			},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			t.Parallel()
+
+			tb := newTestBrowser(t, withFileServer())
+			p := tb.NewPage(nil)
+			opts := &common.FrameGotoOptions{
+				Timeout: common.DefaultTimeout,
+			}
+			_, err := p.Goto(
+				tb.staticURL("react_input.html"),
+				opts,
+			)
+			tt.do(tb, p)
+			require.NoError(t, err)
+		})
+	}
+}
