@@ -4,15 +4,15 @@ import (
 	"net/url"
 	"path/filepath"
 
-	"github.com/spf13/afero"
 	"go.k6.io/k6/lib"
+	"go.k6.io/k6/lib/fsext"
 )
 
 // InitEnvironment contains properties that can be accessed by Go code executed
 // in the k6 init context. It can be accessed by calling common.GetInitEnv().
 type InitEnvironment struct {
 	*lib.TestPreInitState
-	FileSystems map[string]afero.Fs
+	FileSystems map[string]fsext.Fs
 	CWD         *url.URL
 	// TODO: get rid of this type altogether? we won't need it if we figure out
 	// how to handle .tar archive vs regular JS script differences in FileSystems
@@ -34,8 +34,8 @@ func (ie *InitEnvironment) GetAbsFilePath(filename string) string {
 		filename = filepath.Join(ie.CWD.Path, filename)
 	}
 	filename = filepath.Clean(filename)
-	if filename[0:1] != afero.FilePathSeparator {
-		filename = afero.FilePathSeparator + filename
+	if filename[0:1] != fsext.FilePathSeparator {
+		filename = fsext.FilePathSeparator + filename
 	}
 	return filename
 }
