@@ -13,7 +13,7 @@ import (
 	"google.golang.org/protobuf/proto"
 
 	"go.k6.io/k6/cloudapi"
-	"go.k6.io/k6/output/cloud/expv2/pbcloud"
+	"go.k6.io/k6/internal/output/cloud/expv2/pbcloud"
 )
 
 // metricsClient is a Protobuf over HTTP client for sending
